#!/usr/bin/env python

import ConfigParser
import getpass

from insights_coordinator_rhosp.insights_coordinator_infra.parser.config import CoordinatorConfig


class RhospCoordinatorConfig(CoordinatorConfig):

    # Constructor
    def __init__(self, **kwargs):
        super(RhospCoordinatorConfig, self).__init__(**kwargs)

    # Run the configuration utility
    # This will prompt for various user input for configuration variables then
    # Will rewrite the configuration file
    def run_config(self):

        self.logger.vlog(self.language.get_language("Running the RHOSP Insights Coordinator Configuration Utility..."))

        # Configuration container
        config_values = {}

        ############
        # Prompt User for Configuration information
        ####

        # API Configuration Credentials
        #
        # Default API Options to be collected
        config_values['api_options'] = self.constants.api_options

        # SSH Configuration Credentials
        #
        # User
        config_values['ssh_user'] = raw_input(self.language.get_language('Please enter the default SSH User to use for Nodes. (Press Enter for default %s): ') % (self.constants.ssh_user)) or self.constants.ssh_user
        # Port
        config_values['ssh_port'] = raw_input(self.language.get_language('Please enter the default SSH Port to use for Nodes. (Press Enter for default %s): ') % (self.constants.ssh_port)) or self.constants.ssh_port
        # Key
        config_values['ssh_key'] = raw_input(self.language.get_language('Please enter the default SSH Key to use for Nodes. (Press Enter for default %s): ') % (self.constants.ssh_key)) or self.constants.ssh_key

        # Cron Configuration
        #
        # Would you like the cron to run daily?
        cron_string = self.language.get_language("Would you like to enable the RHOSP Insights Coordinator to run daily? Yy/Nn: ")
        yes_values = ['y', 'yes', 'yea', 'yeah', 'yep', 'mmmhmm']
        no_values = ['n', 'no', 'nope', 'naw', 'nah']
        enable_cron = raw_input(cron_string).lower().strip().rstrip()
        while (enable_cron not in yes_values) and (enable_cron not in no_values):
            enable_cron = raw_input(cron_string).lower().strip().rstrip()
        if enable_cron in yes_values:
            config_values['enable_cron'] = True
        else:
            config_values['enable_cron'] = False

        # Environment Variables
        #
        # stackrc
        config_values['stackrc_env'] = raw_input(self.language.get_language("Enter the environment variable file location for the the stackrc environment. (Press Enter for default %s): ") % (self.constants.stackrc_env)) or self.constants.stackrc_env
        # overcloudrc
        config_values['overcloudrc_env'] = raw_input(self.language.get_language("Enter the environment variable file location for the the overcloudrc environment. (Press Enter for default %s): ") % (self.constants.overcloudrc_env)) or self.constants.overcloudrc_env

        ##################
        # Default Values
        ####
        config_values['log_backup_count'] = self.constants.log_backup_count
        config_values['blacklist'] = self.constants.blacklist
        config_values['soscleaner'] = self.constants.soscleaner

        # Write all user configuration values to the file
        self.logger.vlog(self.language.get_language("Finished running the RHOSP Insights Coordinator Configuration Utility. Writing configuration to %s.") % (self.constants.conf_file))
        self.write_config_file(config_values)
        self.setup_config()

        # If the cron job was enabled, symlink that now
        # Otherwise unsymlink the thing
        if config_values['enable_cron']:
            self.cron.setup_cron()
        else:
            self.cron.disable_cron()
