#!/usr/bin/env python

import os
import sys
import subprocess


class RhospCoordinatorCredentials():

    # Containers
    constants = None
    config = None
    logger = None
    stack_credentials = None
    overcloud_credentials = None
    neutron_stack_credentials = None
    neutron_overcloud_credentials = None

    # Constructor
    def __init__(self, **kwargs):
        self.constants = kwargs['constants']
        self.config = kwargs['config']
        self.logger = kwargs['logger']
        self.setup_all_credentials()

    # Setup all of the credentials for API clients
    def setup_all_credentials(self):
        self.setup_stack_credentials()
        self.setup_overcloud_credentials()
        self.setup_neutron_overcloud_credentials()
        self.setup_neutron_stack_credentials()

    # Setup the environment variables
    def setup_env(self, rc_env='stackrc_env'):
        command = ['bash', '-c', 'source %s && env' % (self.config.get_config_var(rc_env))]
        proc = subprocess.Popen(command, stdout=subprocess.PIPE)
        for line in proc.stdout:
            (key, _, value) = line.partition('=')
            os.environ[key] = value.strip()
        proc.communicate()

        # Account for 'sudo hiera admin_password issues'
        # In /home/stack/stackrc there is $(sudo hiera admin_password)
        # This will always output 'nil' or '' because sudo defaults to require a TTY
        # We get around this by running hiera without sudo
        if 'OS_PASSWORD' in os.environ and os.environ['OS_PASSWORD'] == '':
            command = ['hiera', 'admin_password']
            proc = subprocess.Popen(command, stdout=subprocess.PIPE)
            stdout, stderr = proc.communicate()
            os.environ['OS_PASSWORD'] = stdout.strip()

    # Get the overcloud credentials fopr the nova client API
    def get_overcloud_credentials(self):
        if not self.overcloud_credentials:
            self.setup_overcloud_credentials()
        return self.overcloud_credentials

    # Get the stack credentials fopr the nova client API
    def get_stack_credentials(self):
        if not self.stack_credentials:
            self.setup_stack_credentials()
        return self.stack_credentials

    # Get the neutron overcloud client credentials
    def get_neutron_overcloud_credentials(self):
        if not self.neutron_overcloud_credentials:
            self.setup_neutron_overcloud_credentials()
        return self.neutron_overcloud_credentials

    # Get the neutron stack client credentials
    def get_neutron_stack_credentials(self):
        if not self.neutron_stack_credentials:
            self.setup_neutron_stack_credentials()
        return self.neutron_stack_credentials

    # Setup the overcloud credentials for the nova client API
    def setup_overcloud_credentials(self):

        # Source the OVERCLOUDRC Environment
        self.setup_env('overcloudrc_env')

        # Setup the approriate credentials object to pass into the client
        credentials = {}
        credentials['version'] = self.constants.nova_client_version
        credentials['username'] = os.environ['OS_USERNAME']
        credentials['api_key'] = os.environ['OS_PASSWORD']
        credentials['auth_url'] = os.environ['OS_AUTH_URL']
        credentials['project_id'] = os.environ['OS_TENANT_NAME']
        self.overcloud_credentials = credentials
        return credentials

    # Setup the stack credentials for the nova client API
    def setup_stack_credentials(self):

        # Source the STACKRC Environment
        self.setup_env('stackrc_env')

        # Setup the approriate credentials object to pass into the client
        credentials = {}
        credentials['version'] = self.constants.nova_client_version
        credentials['username'] = os.environ['OS_USERNAME']
        credentials['api_key'] = os.environ['OS_PASSWORD']
        credentials['auth_url'] = os.environ['OS_AUTH_URL']
        credentials['project_id'] = os.environ['OS_TENANT_NAME']
        self.stack_credentials = credentials
        return credentials

    # Setup the Neutron OVERCLOUD Credentials
    def setup_neutron_overcloud_credentials(self):

        # Source the OVERCLOUD Environment
        self.setup_env('overcloudrc_env')

        # Make some kwargs
        credentials = {}
        credentials['username'] = os.environ['OS_USERNAME']
        credentials['password'] = os.environ['OS_PASSWORD']
        credentials['tenant_name'] = os.environ['OS_TENANT_NAME']
        credentials['auth_url'] = os.environ['OS_AUTH_URL']
        self.neutron_overcloud_credentials = credentials
        return credentials

    # Setup the Neutron STACK Credentials
    def setup_neutron_stack_credentials(self):

        # Source the STACKRC Environment
        self.setup_env('stackrc_env')

        # Make some kwargs
        credentials = {}
        credentials['username'] = os.environ['OS_USERNAME']
        credentials['password'] = os.environ['OS_PASSWORD']
        credentials['tenant_name'] = os.environ['OS_TENANT_NAME']
        credentials['auth_url'] = os.environ['OS_AUTH_URL']
        self.neutron_stack_credentials = credentials
        return credentials
