#!/usr/bin/env python

###########
# Imports
####
import sys
import os
import logging
from redhat_access_insights import constants as insights_constants


class CoordinatorLogger():

    # Containers
    logger = None
    constants = None
    verbose = False
    config = None
    interactive = None
    language = None
    verbose_logger_setup = False

    # Constructor
    def __init__(self, **kwargs):
        self.constants = kwargs['constants']
        self.config = kwargs['config']
        self.verbose = kwargs['verbose']
        self.language = kwargs['language']
        self.logger = self.set_up_logging(kwargs['constants'])

    # Set the verbose level, currently True or False
    # Need to incorporate a DEBUG/INFO level at some point
    def set_verbosity(self, verbosity):
        self.verbose = verbosity
        if not self.verbose_logger_setup:
            self.setup_verbose_logger()

    # Get interactive
    def get_interactive(self):
        if not self.interactive:
            self.interactive = self.config.get_config_var('interactive')
            if self.interactive:
                self.set_verbosity(True)
        return self.interactive

    #############################################
    # Set up Logging
    ####
    def set_up_logging(self, constants):
        logging_dir = insights_constants.log_dir
        if not os.path.exists(logging_dir):
                os.makedirs(logging_dir, 0700)
        logging_file = os.path.join(logging_dir, constants.logging_file)
        my_logger = logging.getLogger(constants.logger_name)
        my_logger.setLevel(logging.DEBUG)

        file_handler = logging.handlers.RotatingFileHandler(logging_file, backupCount=constants.log_backup_count)
        file_formatter = logging.Formatter(constants.log_formatter)
        file_handler.setFormatter(file_formatter)
        my_logger.addHandler(file_handler)

        if not self.get_interactive() and self.verbose:
            self.setup_verbose_logger()

        return my_logger

    def setup_verbose_logger(self):
        my_logger = logging.getLogger(self.constants.logger_name)
        console_handler = logging.StreamHandler(sys.stdout)
        console_formatter = logging.Formatter(self.constants.log_console_formatter)
        console_handler.setFormatter(console_formatter)
        my_logger.addHandler(console_handler)
        self.verbose_logger_setup = True

    ###############
    # Verbose log
    ####
    def vlog(self, text, level="INFO"):
        if level == "ERROR":
            self.logger.error(text)
        elif level == "DEBUG":
            self.logger.debug(text)
        elif level == "INFO":
            self.logger.info(text)
        else:
            self.logger.info(text)

        interactive = self.get_interactive()
        if interactive is True:
            continue_string = self.language.get_language("%s (Continue? YyENTER/Nn): ") % (text)
            yes_values = ['y', 'yes', 'yea', 'yeah', 'yep', 'mmmhmm']
            no_values = ['n', 'no', 'nope', 'naw', 'nah']
            continue_execution = raw_input(continue_string).lower().strip().rstrip() or True
            while not continue_execution and (continue_execution not in yes_values) and \
                    (continue_execution not in no_values):
                continue_execution = raw_input(continue_string).lower().strip().rstrip() or True
            if not continue_execution or continue_execution in no_values:
                sys.exit(self.language.get_language("Interactive mode exiting Coordinator Insights execution..."))
