#!/usr/bin/env python

##########
# Imports
####
from os import path
from urlparse import urlparse
from copy import copy
from optparse import Option, OptionValueError


class CoordinatorCustomOption(Option, object):

    custom_types = ('port', 'file', 'url')
    TYPES = Option.TYPES + custom_types
    TYPE_CHECKER = copy(Option.TYPE_CHECKER)

    def __init__(self, *args, **kwargs):
        """
        OVERRIDE the Options init function to setup custom type checkers
        Then run the standard options parser initialization
        """
        for custom_type in self.custom_types:
            self.TYPE_CHECKER[custom_type] = getattr(self, "check_" + custom_type)
        super(CoordinatorCustomOption, self).__init__(*args, **kwargs)

    def check_port(self, option, opt, value):
        """
        Check for a valid port range
        """
        try:
            num = int(value)
            # port is a 16-bit unsigned integer
            # https://en.wikipedia.org/wiki/Port_(computer_networking)
            if not 0 <= num <= 65535:
                raise ValueError
            return num
        except ValueError:
            raise OptionValueError("option %s: invalid port: %r" % (opt, value))

    def check_file(self, option, opt, value):
        """
        Check for a valid file path
        and if the file exists
        """
        if path.isfile(value):
            return value
        else:
            raise OptionValueError("option %s: invalid file: %r" % (opt, value))

    def check_url(self, option, opt, value):
        """
        Check for a valid URL
        """
        url = urlparse(value)
        if url.scheme and url.netloc:
            return value
        else:
            raise OptionValueError("option %s: invalid url: %r" % (opt, value))
