#!/usr/bin/env python
#############
# TODO: Need to incorporate keys and ports in this
######
import paramiko


class CoordinatorSSH(object):

    # Containers
    ssh_client = None
    constants = None
    logger = None
    config = None
    language = None

    # Constructor
    def __init__(self, **kwargs):
        self.constants = kwargs['constants']
        self.logger = kwargs['logger']
        self.config = kwargs['config']
        self.language = kwargs['language']
        self.setup_ssh_client()

    # Setup the base ssh client
    def setup_ssh_client(self):
        client = paramiko.SSHClient()
        client.load_system_host_keys()
        client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        self.ssh_client = client
        return client

    # Get the ssh client connection
    def get_ssh_client(self):
        if not self.ssh_client:
            self.ssh_client = self.setup_ssh_client()
        return self.ssh_client

    # Get a ssh client connection for a specific hypervisor/node
    def get_ssh_client_connection(self, client, username=None, key_filename=None):
        ssh_client = self.get_ssh_client()
        if not username:
            username = self.config.get_config_var('ssh_user', True)
        if not key_filename:
            key = self.config.get_config_var('ssh_key', True)
        try:
            ssh_client.connect(client, username=username, key_filename=key)
        except:
            return False
        return ssh_client

    # Run an ssh command on client
    # Takes a paramiko ssh connection
    def _run_command_on_client(self, ssh_command, ssh_client, username=None, key=None):
        ssh_client = self.get_ssh_client_connection(ssh_client, username, key)
        stdin, stdout, stderr = ssh_client.exec_command(ssh_command)
        return {'stdin': stdin, 'stdout': stdout, 'stderr': stderr}

    # Run an ssh command on client
    # Takes a hypervisor/node string
    def run_command_on_client(self, ssh_command, ssh_client_string, username=None, key=None):
        return self._run_command_on_client(ssh_command, ssh_client_string, username, key)
