#!/usr/bin/env python

import os
import sys

from redhat_access_insights.soscleaner import SOSCleaner


class CoordinatorCleaner(object):

    # Containers
    constants = None
    logger = None
    config = None
    utilities = None
    cleaner = None
    language = None

    # Constructor
    def __init__(self, **kwargs):
        self.constants = kwargs['constants']
        self.logger = kwargs['logger']
        self.config = kwargs['config']
        self.utilities = kwargs['utilities']
        self.language = kwargs['language']
        self.setup_cleaner()

    """
    Clean an archive
    Takes an absolute folder name location to a archive
    Will not clean sub archives (.tar,.gz files) within the folder
    Everything must be in folders
    """
    def clean_archive(self, archive_file_name):

        # Run the actual SOSCleaner over the archive
        self.logger.vlog(self.language.get_language("Running SOSCleaner on %s.") % (archive_file_name))
        cleaner = self.get_cleaner()
        cleaner.clean_report(self.get_cleaner_options(), archive_file_name)

        # Obtain the soscleaner prefix that was generated
        # This is used to remove any artfiacts the soscleaner generates in /tmp/current-coordinator-working-directory
        soscleaner_prefix = self.get_prefix()

        # Remove the artifacts but keep the cleaned GZ.
        self.remove_artifacts(soscleaner_prefix)

    # Remove the created soscleaner .tar.gz archive
    def remove_soscleaner_archive(self):
        os.remove(os.path.join(self.utilities.get_tmpdir(), self.get_prefix() + '.tar.gz'))

    # Remove artificats associated with a soscleaner execution
    def remove_artifacts(self, soscleaner_prefix):
        for f in os.listdir(self.utilities.get_tmpdir()):
            if f.startswith(soscleaner_prefix) and not f.endswith('.tar.gz'):
                self.logger.vlog(self.language.get_language('Removing soscleaner artifact %s') % (f))
                os.remove(os.path.join(self.utilities.get_tmpdir(), f))

    # Get the current soscleaner prefix
    def get_prefix(self):
        return "soscleaner-%s" % self.get_cleaner().uuid

    # Get the options for the SOSCleaner operation
    # TODO: This should be abstracted out into cleaner_options.py or some other class
    def get_cleaner_options(self):
        class Obj:
            def __init__(self, **kwargs):
                self.__dict__.update(kwargs)
        clean_opts = Obj(report_dir=self.utilities.get_tmpdir(), domains=[], files=[],
                         quiet=True, keyword_file=None,
                         keywords=None, hostname_path=None)
        return clean_opts

    # Get the SOSCleaner instance
    def get_cleaner(self):
        if not self.cleaner:
            self.setup_cleaner()
        return self.cleaner

    # Setup the SOSCleaner instance
    def setup_cleaner(self):
        cleaner = None
        try:
            cleaner = SOSCleaner(quiet=True)
        except:
            sys.exit(self.language.get_language("Red Hat Access Insights SOSCleaner libraries not found. "
                                                "Coordinator is exiting."))
        self.cleaner = cleaner
        return self.cleaner
