#!/usr/bin/env python
import os
import sys


class CoordinatorCron(object):

    # Containers
    constants = None
    logger = None
    config = None
    language = None

    # Constructor
    def __init__(self, **kwargs):
        self.constants = kwargs['constants']
        self.config = kwargs['config']
        self.logger = kwargs['logger']
        self.language = kwargs['language']

    # Check if the cron file exists
    def cron_exists(self):
        self.logger.vlog(self.language.get_language("Checking if cron job exists..."))
        if self.constants.cron_file and self.constants.cron_file != "":
            return os.path.exists(self.config.get_config_var('cron_symlink'))
        else:
            return False

    # Perform cron symlink
    def setup_cron(self):
        self.logger.vlog(self.language.get_language("Setting up cron job..."))
        cron_symlink = self.config.get_config_var('cron_symlink')

        # If there is not a valid configuration setting
        # AND
        # there is not a valid cron file symlink constant
        if not self.constants.cron_file and not cron_symlink:
            return False

        # Make sure the cron file that we are going to symlink actually exists
        if not os.path.isfile(self.constants.cron_file):
            sys.exit(self.language.get_language("Cannot setup the Coordinator Cron Job. Coordinator installation is missing "
                                                "Cron Job file. Please re-install package."))

        # If there is already a symlink in place, then remove it first
        if os.path.isfile(cron_symlink):
            os.remove(cron_symlink)

        # Perform the symlink
        os.symlink(self.constants.cron_file, cron_symlink)
        return True

    # Remove cron symlink
    def disable_cron(self):
        self.logger.vlog(self.language.get_language("Disabling cron job..."))
        cron_symlink = self.config.get_config_var('cron_symlink')

        # If the cron symlink location is not defined then we cannot remove the file
        if not cron_symlink:
            return False

        # If the file exists then remove it
        if os.path.isfile(cron_symlink):
            os.remove(self.config.get_config_var('cron_symlink'))
            return True
        else:
            return False
