#!/usr/bin/env python

import optparse
import tempfile

from insights_coordinator_rhosp.insights_coordinator_infra.parser.options_parser import CoordinatorParser
from insights_coordinator_rhosp.insights_coordinator_infra.parser.options import CoordinatorCustomOption as RhospCoordinatorCustomOption


class RhospCoordinatorParser(CoordinatorParser):

    # Constructor
    def __init__(self, **kwargs):
        super(RhospCoordinatorParser, self).__init__(**kwargs)
        self.setup_options()
        self.setup_parser()

    # Setup the Options
    def setup_options(self):
        self.options = [

            # Get the current version of the coordinator
            optparse.make_option('--version', dest='version',
                                 help=self.language.get_language("This outputs the current version of the coordinator."),
                                 action='store_true',
                                 default=False),

            # Configuration utility
            optparse.make_option('--configure', dest='configure',
                                 help=self.language.get_language("Run the RHOSP Configuration utility. "
                                                                 "This will re-write the Coordinator configuration "
                                                                 "file to /etc/redhat-access-insights/insights-coordinator-rhosp.conf. "
                                                                 "After running this utility the Coordinator will exit."),
                                 action='store_true',
                                 default=self.constants.configure),

            # Make the Coordinator interactive
            optparse.make_option('--interactive', dest='interactive',
                                 help=self.language.get_language("This prompts for the exeuction of each step. "
                                                                 "This implies --verbose."),
                                 action='store_true',
                                 default=self.constants.interactive),

            # Make things Verbose
            optparse.make_option('-v', '--verbose', dest='verbose',
                                 help=self.language.get_language('In addition to logging to the Coordinator Logs, '
                                                                 'print output to the console.'),
                                 action='store_true',
                                 default=self.config.get_config_var('verbose')),

            # Archive Only
            optparse.make_option('--archive-only', dest='archive_only',
                                 help=self.language.get_language('Only create the Coordinator Archive in /tmp. '
                                                                 'This will not upload the final Archive to Red Hat.'),
                                 action='store_true',
                                 default=self.config.get_config_var('archive_only')),

            # Test API
            optparse.make_option('--test-api', dest='test_api',
                                 help=self.language.get_language('Only test the RHOSP Director API Connection. '
                                                                 'Coordinator will exit after test.'),
                                 action='store_true',
                                 default=self.constants.test_api),

            # Only display the hosts attached to the Director
            optparse.make_option("--hosts-only",
                                 dest="hosts_only",
                                 help=self.language.get_language("Only retrieve the host list."),
                                 action="store_true",
                                 default=self.constants.hosts_only),

            # SSH User
            optparse.make_option("--ssh-user",
                                 dest="ssh_user",
                                 help=self.language.get_language("ssh user to use for nodes"),
                                 default=self.config.get_config_var('ssh_user')),

            # SSH Key
            RhospCoordinatorCustomOption("--ssh-key",
                                         dest="ssh_key",
                                         help=self.language.get_language("ssh key to use for nodes"),
                                         type="file",
                                         default=self.config.get_config_var('ssh_key')),

            # SSH Port
            RhospCoordinatorCustomOption("--ssh-port",
                                         dest="ssh_port",
                                         help=self.language.get_language("ssh port to use for nodes"),
                                         type="port",
                                         default=self.config.get_config_var('ssh_port')),

            # Disable Cron
            optparse.make_option('--disable-cron', dest='disable_cron',
                                 help=self.language.get_language('Will unlink and disable the Coordinator Cron Job.'),
                                 action='store_true',
                                 default=self.constants.disable_cron),

            # Enable Cron
            optparse.make_option('--enable-cron', dest='enable_cron',
                                 help=self.language.get_language('Will link and enable the Coordinator Cron Job.'),
                                 action='store_true',
                                 default=self.constants.enable_cron),

            # API Options
            optparse.make_option('--api-options', dest='api_options',
                                 help=self.language.get_language('Will allow using specific RHOSP Director API Options '
                                                                 'for retrieval from the API. Will temporarily override '
                                                                 'any existing API Options configured.'),
                                 default=self.config.get_config_var('api_options')),

            # Manually pass in the environment variables for the stack
            RhospCoordinatorCustomOption('--stack-environment', dest='stackrc_env',
                                         help=self.language.get_language('Manually specificy the '
                                                                         'environment variables to use for the stack'),
                                         type="file",
                                         default=self.config.get_config_var('stackrc_env')),

            # Manually pass in the environment variables for the overcloud
            RhospCoordinatorCustomOption('--overcloud-environment', dest='overcloudrc_env',
                                         help=self.language.get_language('Manually specificy the '
                                                                         'environment variables to use for the overcloud'),
                                         type="file",
                                         default=self.config.get_config_var('overcloudrc_env')),

            # Manually run the soscleaner on the generated archive for this execution
            optparse.make_option('--run-soscleaner', dest='soscleaner',
                                 help=self.language.get_language('Manually trigger the SOSCleaner '
                                                                 'to be ran over the generated archive '
                                                                 'for this execution of the Coordinator.'),
                                 action='store_true',
                                 default=self.config.get_config_var('soscleaner')),

            # Blacklist any nodes/hostnames
            optparse.make_option('--blacklist', dest='blacklist',
                                 help=self.language.get_language('Will blacklist certain Nodes '
                                                                 'from the Insights data collection. '
                                                                 'This is a comma separated list of '
                                                                 'hostnames. Any hostname matching in '
                                                                 'this string will not be collected. '
                                                                 'This will temporarily override any '
                                                                 'currently configured blacklist defined '
                                                                 'in the Coordinator configuration files. '
                                                                 'Wildcards are accepted.'),
                                 default=self.config.get_config_var('blacklist'))
        ]
